@@ -6,7 +6,7 @@ int_or_none, parse_iso8601, urljoin = ytdl.import_from(
     'utils', ['int_or_none', 'parse_iso8601', 'urljoin'])
 
 
-__version__ = '0.2.0'
+__version__ = '0.3.0'
 
 
 plugin = ExtractorPlugin(__name__)
@@ -14,6 +14,8 @@ plugin = ExtractorPlugin(__name__)
 
 class WASDTVBaseExtractor(Extractor):
 
+    DLP_BASE_URL = r'https?://(www\.)?wasd\.tv/'
+
     _API_BASE = 'https://wasd.tv/api/'
     _THUMBNAIL_SIZES = ('small', 'medium', 'large')
 
@@ -48,6 +50,11 @@ class WASDTVBaseExtractor(Extractor):
                 f'{self.IE_NAME} returned error: {error_code}', expected=True)
         return response['result']
 
+    def _extract_formats(self, m3u8_url, video_id):
+        formats = self._extract_m3u8_formats(m3u8_url, video_id, 'mp4')
+        self._sort_formats(formats)
+        return formats
+
     def _extract_thumbnails(self, thumbnails_dict):
         if not thumbnails_dict:
             return None
@@ -104,23 +111,24 @@ class WASDTVBaseVideoExtractor(WASDTVBaseExtractor):
                 else 'stream_total_viewers'
             )),
             'is_live': is_live,
-            'formats': self._extract_m3u8_formats(media_url, video_id, 'mp4'),
+            'formats': self._extract_formats(media_url, video_id),
         }
 
 
 @plugin.register('stream')
 class WASDTVStreamExtractor(WASDTVBaseVideoExtractor):
 
-    _VALID_URL = r'https?://wasd\.tv/(?P<id>[^/#?]+)$'
+    DLP_REL_URL = r'(?:channel/(?P<channel_id>\d+)|(?P<nickname>[^/#?]+))/?$'
 
     def _get_container(self, url):
-        nickname = self._match_id(url)
-        channel = self._fetch(
-            'channels', 'nicknames', nickname,
-            item_id=nickname,
-            description='channel',
-        )
-        channel_id = channel['channel_id']
+        channel_id, nickname = self.dlp_match(
+            url).group('channel_id', 'nickname')
+        if not channel_id:
+            channel_id = self._fetch(
+                'channels', 'nicknames', nickname,
+                item_id=nickname,
+                description='channel',
+            )['channel_id']
         containers = self._fetch(
             'v2', 'media-containers',
             query={
@@ -142,7 +150,7 @@ class WASDTVStreamExtractor(WASDTVBaseVideoExtractor):
 @plugin.register('record')
 class WASDTVRecordExtractor(WASDTVBaseVideoExtractor):
 
-    _VALID_URL = r'https?://wasd\.tv/[^/#?]+/videos\?record=(?P<id>\d+)$'
+    DLP_REL_URL = r'[^/#?]+/videos\?record=(?P<id>\d+)$'
 
     def _get_container(self, url):
         container_id = self._match_id(url)
@@ -162,7 +170,7 @@ class WASDTVRecordExtractor(WASDTVBaseVideoExtractor):
 @plugin.register('clip')
 class WASDTVClipExtractor(WASDTVBaseExtractor):
 
-    _VALID_URL = r'https?://wasd\.tv/[^/#?]+/clips\?clip=(?P<id>\d+)$'
+    DLP_REL_URL = r'[^/#?]+/clips\?clip=(?P<id>\d+)$'
 
     def _real_extract(self, url):
         clip_id = self._match_id(url)
@@ -181,6 +189,5 @@ class WASDTVClipExtractor(WASDTVBaseExtractor):
             'thumbnails': self._extract_thumbnails(clip_data.get('preview')),
             'timestamp': parse_iso8601(clip.get('created_at')),
             'view_count': int_or_none(clip.get('clip_views_count')),
-            'formats': self._extract_m3u8_formats(
-                clip_data['url'], clip_id, 'mp4'),
+            'formats': self._extract_formats(clip_data['url'], clip_id),
         }
